==> pyametista-0.1.6.tar.gz: pyametista-0.1.6/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyametista',
 'pyametista.adapters',
 'pyametista.engine',
 'pyametista.engine.bands',
 'pyametista.engine.components',
 'pyametista.exports']

package_data = \
{'': ['*'],
 'pyametista': ['fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf']}

install_requires = \
['mysql-connector-python>=8.0.28,<9.0.0',
 'psycopg2-binary>=2.9.3,<3.0.0',
 'reportlab>=3.6.8,<4.0.0']

setup_kwargs = {
    'name': 'pyametista',
    'version': '0.1.6',
    'description': 'Módulo Python para geração de PDF utilizando arquivos .jrxml (JasperReports)',
    'long_description': None,
    'author': 'Bruno Souza',
    'author_email': 'bruno@komu.com.br',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)

==> pyametista-0.1.7.tar.gz: pyametista-0.1.7/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pyametista',
 'pyametista.adapters',
 'pyametista.engine',
 'pyametista.engine.bands',
 'pyametista.engine.components',
 'pyametista.exports']

package_data = \
{'': ['*'],
 'pyametista': ['fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/LICENSE.txt',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-Bold.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-BoldItalic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Italic.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/OpenSans-Regular.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-Bold.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-BoldItalic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Italic.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/Roboto-Regular.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Bold.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf',
                'fonts/RobotoSlab-Regular.ttf']}

install_requires = \
['reportlab>=3.6.8,<4.0.0']

setup_kwargs = {
    'name': 'pyametista',
    'version': '0.1.7',
    'description': 'Módulo Python para geração de PDF utilizando arquivos .jrxml (JasperReports)',
    'long_description': None,
    'author': 'Bruno Souza',
    'author_email': 'bruno@komu.com.br',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
